AutohostUpdateEventData

Struct AutohostUpdateEventData 

pub struct AutohostUpdateEventData {
    pub battle_id: Uuid,
    pub time: UnixTime,
    pub update: AutohostUpdateEventDataUpdate,
}
AutohostUpdateEventData

JSON schema
{
 "title": "AutohostUpdateEventData",
 "type": "object",
 "required": [
   "battleId",
   "time",
   "update"
 ],
 "properties": {
   "battleId": {
     "type": "string",
     "format": "uuid"
   },
   "time": {
     "$ref": "#/definitions/unixTime"
   },
   "update": {
     "anyOf": [
       {
         "title": "StartUpdate",
         "description": "The battle has started.",
         "type": "object",
         "required": [
           "type"
         ],
         "properties": {
           "type": {
             "const": "start"
           }
         }
       },
       {
         "title": "FinishedUpdate",
         "description": "The battle finished, generated once per every single player reporting who won.",
         "type": "object",
         "required": [
           "type",
           "userId",
           "winningAllyTeams"
         ],
         "properties": {
           "type": {
             "const": "finished"
           },
           "userId": {
             "$ref": "#/definitions/userId"
           },
           "winningAllyTeams": {
             "description": "Ally team IDs",
             "type": "array",
             "items": {
               "type": "integer"
             },
             "minItems": 1
           }
         }
       },
       {
         "title": "EngineMessageUpdate",
         "description": "A message from the engine, e.g. some ip is trying to connect.",
         "type": "object",
         "required": [
           "message",
           "type"
         ],
         "properties": {
           "message": {
             "type": "string"
           },
           "type": {
             "const": "engine_message"
           }
         }
       },
       {
         "title": "EngineWarningUpdate",
         "description": "A warning from the engine.",
         "type": "object",
         "required": [
           "message",
           "type"
         ],
         "properties": {
           "message": {
             "type": "string"
           },
           "type": {
             "const": "engine_warning"
           }
         }
       },
       {
         "title": "EngineQuitUpdate",
         "description": "The engine process for battle has quit cleanly, no more updates will be sent for this battle.",
         "type": "object",
         "required": [
           "type"
         ],
         "properties": {
           "type": {
             "const": "engine_quit"
           }
         }
       },
       {
         "title": "EngineCrashUpdate",
         "description": "The engine process for battle has crashed, no more updates will be sent for this battle.",
         "type": "object",
         "required": [
           "type"
         ],
         "properties": {
           "details": {
             "description": "Optional, short, details of the crash.",
             "type": "string"
           },
           "type": {
             "const": "engine_crash"
           }
         }
       },
       {
         "title": "PlayerJoinedUpdate",
         "type": "object",
         "required": [
           "playerNumber",
           "type",
           "userId"
         ],
         "properties": {
           "playerNumber": {
             "description": "Player number in the game, can be useful for custom commands",
             "type": "integer"
           },
           "type": {
             "const": "player_joined"
           },
           "userId": {
             "$ref": "#/definitions/userId"
           }
         }
       },
       {
         "title": "PlayerLeftUpdate",
         "type": "object",
         "required": [
           "reason",
           "type",
           "userId"
         ],
         "properties": {
           "reason": {
             "enum": [
               "lost_connection",
               "left",
               "kicked"
             ]
           },
           "type": {
             "const": "player_left"
           },
           "userId": {
             "$ref": "#/definitions/userId"
           }
         }
       },
       {
         "title": "PlayerChatUpdate",
         "anyOf": [
           {
             "type": "object",
             "required": [
               "destination",
               "message",
               "type",
               "userId"
             ],
             "properties": {
               "destination": {
                 "enum": [
                   "allies",
                   "all",
                   "spectators"
                 ]
               },
               "message": {
                 "type": "string"
               },
               "type": {
                 "const": "player_chat"
               },
               "userId": {
                 "$ref": "#/definitions/userId"
               }
             }
           },
           {
             "type": "object",
             "required": [
               "destination",
               "message",
               "toUserId",
               "type",
               "userId"
             ],
             "properties": {
               "destination": {
                 "const": "player"
               },
               "message": {
                 "type": "string"
               },
               "toUserId": {
                 "$ref": "#/definitions/userId"
               },
               "type": {
                 "const": "player_chat"
               },
               "userId": {
                 "$ref": "#/definitions/userId"
               }
             }
           }
         ]
       },
       {
         "title": "PlayerDefeatedUpdate",
         "type": "object",
         "required": [
           "type",
           "userId"
         ],
         "properties": {
           "type": {
             "const": "player_defeated"
           },
           "userId": {
             "$ref": "#/definitions/userId"
           }
         }
       },
       {
         "title": "LuaMsgUpdate",
         "description": "This update is generated only for messages matching luamsgRegexp set in the battle start script.",
         "type": "object",
         "required": [
           "data",
           "script",
           "type",
           "userId"
         ],
         "properties": {
           "data": {
             "type": "string",
             "contentEncoding": "base64",
             "contentMediaType": "application/octet-stream"
           },
           "script": {
             "enum": [
               "ui",
               "game",
               "rules"
             ]
           },
           "type": {
             "const": "luamsg"
           },
           "uiMode": {
             "description": "Set when script is 'ui'",
             "enum": [
               "all",
               "allies",
               "spectators"
             ]
           },
           "userId": {
             "$ref": "#/definitions/userId"
           }
         }
       }
     ]
   }
 }
}

Fields

battle_id: Uuidtime: UnixTimeupdate: AutohostUpdateEventDataUpdate

Implementations