pub struct EngineCrashUpdate {
pub details: Option<String>,
pub type_: Value,
}Expand description
The engine process for battle has crashed, no more updates will be sent for this battle.
JSON schema
{
"title": "EngineCrashUpdate",
"description": "The engine process for battle has crashed, no more updates will be sent for this battle.",
"type": "object",
"required": [
"type"
],
"properties": {
"details": {
"description": "Optional, short, details of the crash.",
"type": "string"
},
"type": {
"const": "engine_crash"
}
}
}Fields
details: Option<String>Optional, short, details of the crash.
type_: ValueImplementations
Sourceimpl EngineCrashUpdate
impl EngineCrashUpdate
pub fn builder() -> EngineCrashUpdate