pub struct EngineQuitUpdate {
pub type_: Value,
}Expand description
The engine process for battle has quit cleanly, no more updates will be sent for this battle.
JSON schema
{
"title": "EngineQuitUpdate",
"description": "The engine process for battle has quit cleanly, no more updates will be sent for this battle.",
"type": "object",
"required": [
"type"
],
"properties": {
"type": {
"const": "engine_quit"
}
}
}Fields
type_: ValueImplementations
Sourceimpl EngineQuitUpdate
impl EngineQuitUpdate
pub fn builder() -> EngineQuitUpdate