LobbyOverview

Struct LobbyOverview 

pub struct LobbyOverview {
    pub current_battle: Option<LobbyOverviewCurrentBattle>,
    pub engine_version: String,
    pub game_version: String,
    pub id: String,
    pub map_name: String,
    pub max_player_count: i64,
    pub name: String,
    pub player_count: i64,
}
Simplified view of a lobby for list display purposes.

JSON schema
{
 "description": "Simplified view of a lobby for list display purposes.",
 "type": "object",
 "required": [
   "currentBattle",
   "engineVersion",
   "gameVersion",
   "id",
   "mapName",
   "maxPlayerCount",
   "name",
   "playerCount"
 ],
 "properties": {
   "currentBattle": {
     "anyOf": [
       {
         "type": "object",
         "required": [
           "startedAt"
         ],
         "properties": {
           "startedAt": {
             "$ref": "#/definitions/unixTime"
           }
         }
       },
       {
         "type": "null"
       }
     ]
   },
   "engineVersion": {
     "type": "string"
   },
   "gameVersion": {
     "type": "string"
   },
   "id": {
     "type": "string"
   },
   "mapName": {
     "type": "string"
   },
   "maxPlayerCount": {
     "type": "integer"
   },
   "name": {
     "type": "string"
   },
   "playerCount": {
     "type": "integer"
   }
 }
}

Fields

current_battle: Option<LobbyOverviewCurrentBattle>engine_version: Stringgame_version: Stringid: Stringmap_name: Stringmax_player_count: i64name: Stringplayer_count: i64

Implementations