pub struct LobbyUpdatedEventDataCurrentBattle {
pub id: String,
pub started_at: UnixTime,
}Expand description
If a battle is currently happening, here are the info
JSON schema
{
"description": "If a battle is currently happening, here are the info",
"type": "object",
"required": [
"id",
"startedAt"
],
"properties": {
"id": {
"type": "string"
},
"startedAt": {
"$ref": "#/definitions/unixTime"
}
}
}Fields
id: Stringstarted_at: UnixTimeImplementations