pub struct LobbyUpdatedEventDataCurrentVote {
pub action: Option<VoteActions>,
pub id: String,
pub initiator: Option<UserId>,
pub majority: Option<NonZeroU64>,
pub quorum: Option<NonZeroU64>,
pub until: Option<UnixTime>,
pub voters: HashMap<LobbyUpdatedEventDataCurrentVoteVotersKey, LobbyUpdatedEventDataCurrentVoteVotersValue>,
}Expand description
LobbyUpdatedEventDataCurrentVote
JSON schema
{
"type": "object",
"required": [
"id"
],
"properties": {
"action": {
"$ref": "#/definitions/voteActions"
},
"id": {
"type": "string"
},
"initiator": {
"$ref": "#/definitions/userId"
},
"majority": {
"description": "votes passes when number(yes) >= majority",
"type": "integer",
"minimum": 1.0
},
"quorum": {
"description": "this many player must vote for the vote to be valid at all.",
"type": "integer",
"minimum": 1.0
},
"until": {
"$ref": "#/definitions/unixTime"
},
"voters": {
"type": "object",
"patternProperties": {
"^.*$": {
"type": "object",
"required": [
"vote"
],
"properties": {
"vote": {
"enum": [
"pending",
"yes",
"no",
"abstain"
]
}
}
}
}
}
}
}Fields
action: Option<VoteActions>id: Stringinitiator: Option<UserId>majority: Option<NonZeroU64>votes passes when number(yes) >= majority
quorum: Option<NonZeroU64>this many player must vote for the vote to be valid at all.
until: Option<UnixTime>voters: HashMap<LobbyUpdatedEventDataCurrentVoteVotersKey, LobbyUpdatedEventDataCurrentVoteVotersValue>Implementations