pub struct PlayerJoinedUpdate {
pub player_number: i64,
pub type_: Value,
pub user_id: UserId,
}Expand description
PlayerJoinedUpdate
JSON schema
{
"title": "PlayerJoinedUpdate",
"type": "object",
"required": [
"playerNumber",
"type",
"userId"
],
"properties": {
"playerNumber": {
"description": "Player number in the game, can be useful for custom commands",
"type": "integer"
},
"type": {
"const": "player_joined"
},
"userId": {
"$ref": "#/definitions/userId"
}
}
}Fields
player_number: i64Player number in the game, can be useful for custom commands
type_: Valueuser_id: UserIdImplementations
Sourceimpl PlayerJoinedUpdate
impl PlayerJoinedUpdate
pub fn builder() -> PlayerJoinedUpdate